CREATE TABLE HIK_MAJ_EV_TYPE (
	HIK_MAJ_EV_TYPE_ID NUMBER NOT NULL,
	EV_TYPE VARCHAR2(100 CHAR) NOT NULL,
	CODE VARCHAR2(20 CHAR) NOT NULL,
	NAME VARCHAR2(50 CHAR) NOT NULL,
	CONSTRAINT HIK_MAJ_EV_TYPE_PK PRIMARY KEY(HIK_MAJ_EV_TYPE_ID),
	CONSTRAINT HIK_MAJ_EV_TYPE_PL_U1 UNIQUE(EV_TYPE),
	CONSTRAINT HIK_MAJ_EV_TYPE_PL_U2 UNIQUE(CODE)
);

INSERT INTO HIK_MAJ_EV_TYPE (HIK_MAJ_EV_TYPE_ID, EV_TYPE, CODE,	NAME) VALUES (0, 'UNKNOWN', '0', 'Unknown event');
INSERT INTO HIK_MAJ_EV_TYPE (HIK_MAJ_EV_TYPE_ID, EV_TYPE, CODE,	NAME) VALUES (1, 'MAJOR_ALARM', '0x1', 'Major alarm');
INSERT INTO HIK_MAJ_EV_TYPE (HIK_MAJ_EV_TYPE_ID, EV_TYPE, CODE,	NAME) VALUES (2, 'MAJOR_EXCEPTION', '0x2', 'Major exception');
INSERT INTO HIK_MAJ_EV_TYPE (HIK_MAJ_EV_TYPE_ID, EV_TYPE, CODE,	NAME) VALUES (3, 'MAJOR_OPERATION', '0x3', 'Major operation');
INSERT INTO HIK_MAJ_EV_TYPE (HIK_MAJ_EV_TYPE_ID, EV_TYPE, CODE,	NAME) VALUES (5, 'MAJOR_EVENT', '0x5', 'Major event');

CREATE TABLE HIK_MIN_EV_TYPE (
	HIK_MIN_EV_TYPE_ID NUMBER NOT NULL,
	HIK_MAJ_EV_TYPE_ID NUMBER NOT NULL,
	MIN_EV_ID INTEGER,
	EV_TYPE VARCHAR2(100 CHAR) NOT NULL,
	CODE VARCHAR2(20 CHAR) NOT NULL,
	NAME VARCHAR2(200 CHAR) NOT NULL,
	CONSTRAINT HIK_MIN_EV_TYPE_PK PRIMARY KEY(HIK_MIN_EV_TYPE_ID),
	CONSTRAINT HIK_MIN_EV_TYPE_U1 UNIQUE(HIK_MAJ_EV_TYPE_ID, MIN_EV_ID),
	CONSTRAINT HIK_MIN_EV_TYPE_U2 UNIQUE(HIK_MAJ_EV_TYPE_ID, EV_TYPE),
	CONSTRAINT HIK_MIN_EV_TYPE_U3 UNIQUE(HIK_MAJ_EV_TYPE_ID, CODE),
	CONSTRAINT HIK_MIN_MAX_EV_TYPE_FK FOREIGN KEY (HIK_MAJ_EV_TYPE_ID) REFERENCES HIK_MAJ_EV_TYPE (HIK_MAJ_EV_TYPE_ID)
);

CREATE SEQUENCE HIK_MIN_EV_TYPE_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER NOCYCLE;

CREATE VIEW V_HIK_MIN_EV_TYPE AS
SELECT
	N.HIK_MIN_EV_TYPE_ID,
	N.HIK_MAJ_EV_TYPE_ID,
	N.MIN_EV_ID,
	N.EV_TYPE,
	N.CODE,
	N.NAME,
	M.NAME AS MAJOR_EVENT_NAME
FROM
	HIK_MIN_EV_TYPE N
	LEFT OUTER JOIN HIK_MAJ_EV_TYPE M ON M.HIK_MAJ_EV_TYPE_ID = N.HIK_MAJ_EV_TYPE_ID
;

INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT 0, 0, 'UNKNOWN', 0, '0', 'Unknown event' FROM DUAL;
-- Alarm
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_ALARMIN_SHORT_CIRCUIT', TO_NUMBER('400', 'XXXXXXXXX'), '0x400', 'Zone Short Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_ALARMIN_BROKEN_CIRCUIT', TO_NUMBER('401', 'XXXXXXXXX'), '0x401', 'Zone Disconnected Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_ALARMIN_EXCEPTION', TO_NUMBER('402', 'XXXXXXXXX'), '0x402', 'Zone Exception Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_ALARMIN_RESUME', TO_NUMBER('403', 'XXXXXXXXX'), '0x403', 'Zone Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_HOST_DESMANTLE_ALARM', TO_NUMBER('404', 'XXXXXXXXX'), '0x404', 'Zone Tampering Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_HOST_DESMANTLE_RESUME', TO_NUMBER('405', 'XXXXXXXXX'), '0x405', 'Zone Tampering Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CARD_READER_DESMANTLE_ALARM', TO_NUMBER('406', 'XXXXXXXXX'), '0x406', 'Card Reader Tampering Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CARD_READER_DESMANTLE_RESUME', TO_NUMBER('407', 'XXXXXXXXX'), '0x407', 'Card Reader Tampering Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CASE_SENSOR_ALARM', TO_NUMBER('408', 'XXXXXXXXX'), '0x408', 'Alarm Input Alarm Triggered' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CASE_SENSOR_RESUME', TO_NUMBER('409', 'XXXXXXXXX'), '0x409', 'Alarm Input Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_STRESS_ALARM', TO_NUMBER('40a', 'XXXXXXXXX'), '0x40a', 'Duress Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_OFFLINE_ECENT_NEARLY_FULL', TO_NUMBER('40b', 'XXXXXXXXX'), '0x40b', 'No Memory for Offline Event Storage Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CARD_MAX_AUTHENTICATE_FAIL', TO_NUMBER('40c', 'XXXXXXXXX'), '0x40c', 'Maximum Failed Card Authentications Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_SD_CARD_FULL', TO_NUMBER('40d', 'XXXXXXXXX'), '0x40d', 'SD Card Full Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_LINKAGE_CAPTURE_PIC', TO_NUMBER('40e', 'XXXXXXXXX'), '0x40e', 'Capture Linkage Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_SECURITY_MODULE_DESMANTLE_ALARM', TO_NUMBER('40f', 'XXXXXXXXX'), '0x40f', 'Secure Door Control Unit Tampering Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_SECURITY_MODULE_DESMANTLE_RESUME', TO_NUMBER('410', 'XXXXXXXXX'), '0x410', 'Secure Door Control Unit Tampering Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_FIRE_IMPORT_SHORT_CIRCUIT', TO_NUMBER('415', 'XXXXXXXXX'), '0x415', 'Fire Input Short Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_FIRE_IMPORT_BROKEN_CIRCUIT', TO_NUMBER('416', 'XXXXXXXXX'), '0x416', 'Fire Input Open Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_FIRE_IMPORT_RESUME', TO_NUMBER('417', 'XXXXXXXXX'), '0x417', 'Fire Input Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_FIRE_BUTTON_TRIGGER', TO_NUMBER('418', 'XXXXXXXXX'), '0x418', 'Fire Button Triggered' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_FIRE_BUTTON_RESUME', TO_NUMBER('419', 'XXXXXXXXX'), '0x419', 'Fire Button Resumed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_MAINTENANCE_BUTTON_TRIGGER', TO_NUMBER('41a', 'XXXXXXXXX'), '0x41a', 'Maintenance Button Triggered' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_MAINTENANCE_BUTTON_RESUME', TO_NUMBER('41b', 'XXXXXXXXX'), '0x41b', 'Maintenance Button Resumed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_EMERGENCY_BUTTON_TRIGGER', TO_NUMBER('41c', 'XXXXXXXXX'), '0x41c', 'Panic Button Triggered' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_EMERGENCY_BUTTON_RESUME', TO_NUMBER('41d', 'XXXXXXXXX'), '0x41d', 'Panic Button Resumed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_DISTRACT_CONTROLLER_ALARM', TO_NUMBER('41e', 'XXXXXXXXX'), '0x41e', 'Distributed Elevator Controller Tampering Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_DISTRACT_CONTROLLER_RESUME', TO_NUMBER('41f', 'XXXXXXXXX'), '0x41f', 'Distributed Elevator Controller Tampering Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CHANNEL_CONTROLLER_DESMANTLE_ALARM', TO_NUMBER('422', 'XXXXXXXXX'), '0x422', 'Lane Controller Tampering Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CHANNEL_CONTROLLER_DESMANTLE_RESUME', TO_NUMBER('423', 'XXXXXXXXX'), '0x423', 'Lane Controller Tampering Alarm Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CHANNEL_CONTROLLER_FIRE_IMPORT_ALARM', TO_NUMBER('424', 'XXXXXXXXX'), '0x424', 'Lane Controller Fire Input Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_CHANNEL_CONTROLLER_FIRE_IMPORT_RESUME', TO_NUMBER('425', 'XXXXXXXXX'), '0x425', 'Lane Controller Fire Input Alarm Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_PRINTER_OUT_OF_PAPER', TO_NUMBER('440', 'XXXXXXXXX'), '0x440', 'No Paper in Printer Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 1, 'MINOR_LEGAL_EVENT_NEARLY_FULL', TO_NUMBER('442', 'XXXXXXXXX'), '0x442', 'No Memory Alarm for Valid Offline Event Storage' FROM DUAL;
-- Exception
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_NET_BROKEN', TO_NUMBER('27', 'XXXXXXXXX'), '0x27', 'Network Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_RS485_DEVICE_ABNORMAL', TO_NUMBER('3a', 'XXXXXXXXX'), '0x3a', 'RS485 Connection Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_RS485_DEVICE_REVERT', TO_NUMBER('3b', 'XXXXXXXXX'), '0x3b', 'RS485 Connection Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_DEV_POWER_ON', TO_NUMBER('400', 'XXXXXXXXX'), '0x400', 'Power on' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_DEV_POWER_OFF', TO_NUMBER('401', 'XXXXXXXXX'), '0x401', 'Power off' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_WATCH_DOG_RESET', TO_NUMBER('402', 'XXXXXXXXX'), '0x402', 'Watchdog Reset' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOW_BATTERY', TO_NUMBER('403', 'XXXXXXXXX'), '0x403', 'Low Battery Voltage' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_BATTERY_RESUME', TO_NUMBER('404', 'XXXXXXXXX'), '0x404', 'Battery Voltage Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_AC_OFF', TO_NUMBER('405', 'XXXXXXXXX'), '0x405', 'AC Power Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_AC_RESUME', TO_NUMBER('406', 'XXXXXXXXX'), '0x406', 'AC Power Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_NET_RESUME', TO_NUMBER('407', 'XXXXXXXXX'), '0x407', 'Network Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_FLASH_ABNORMAL', TO_NUMBER('408', 'XXXXXXXXX'), '0x408', 'Flash Reading and Writing Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CARD_READER_OFFLINE', TO_NUMBER('409', 'XXXXXXXXX'), '0x409', 'Card Reader Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CAED_READER_RESUME', TO_NUMBER('40a', 'XXXXXXXXX'), '0x40a', 'Card Reader Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_INDICATOR_LIGHT_OFF', TO_NUMBER('40b', 'XXXXXXXXX'), '0x40b', 'Indicator Turns off' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_INDICATOR_LIGHT_RESUME', TO_NUMBER('40c', 'XXXXXXXXX'), '0x40c', 'Indicator Resumed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CHANNEL_CONTROLLER_OFF', TO_NUMBER('40d', 'XXXXXXXXX'), '0x40d', 'Lane Controller Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CHANNEL_CONTROLLER_RESUME', TO_NUMBER('40e', 'XXXXXXXXX'), '0x40e', 'Lane Controller Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_SECURITY_MODULE_OFF', TO_NUMBER('40f', 'XXXXXXXXX'), '0x40f', 'Secure Door Control Unit Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_SECURITY_MODULE_RESUME', TO_NUMBER('410', 'XXXXXXXXX'), '0x410', 'Secure Door Control Unit Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_BATTERY_ELECTRIC_LOW', TO_NUMBER('411', 'XXXXXXXXX'), '0x411', 'Low Battery Voltage (Only for Face Recognition Terminal)' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_BATTERY_ELECTRIC_RESUME', TO_NUMBER('412', 'XXXXXXXXX'), '0x412', 'Battery Voltage Recovered (Only for Face Recognition Terminal)' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_CONTROL_NET_BROKEN', TO_NUMBER('413', 'XXXXXXXXX'), '0x413', 'Network of Distributed Access Controller Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_CONTROL_NET_RSUME', TO_NUMBER('414', 'XXXXXXXXX'), '0x414', 'Network of Distributed Access Controller Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_MASTER_RS485_LOOPNODE_BROKEN', TO_NUMBER('415', 'XXXXXXXXX'), '0x415', 'RS485 Loop of Master Access Controller Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_MASTER_RS485_LOOPNODE_RESUME', TO_NUMBER('416', 'XXXXXXXXX'), '0x416', 'RS485 Loop of Master Access Controller Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_CONTROL_OFFLINE', TO_NUMBER('417', 'XXXXXXXXX'), '0x417', 'Distributed Access Controller Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_CONTROL_RESUME', TO_NUMBER('418', 'XXXXXXXXX'), '0x418', 'Distributed Access Controller Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_DOWNSIDE_RS485_LOOPNODE_BROKEN', TO_NUMBER('419', 'XXXXXXXXX'), '0x419', 'Downstream RS485 Loop of Distributed Access Control Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_DOWNSIDE_RS485_LOOPNODE_RESUME', TO_NUMBER('41a', 'XXXXXXXXX'), '0x41a', 'Downstream RS485 Loop of Distributed Access Control Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_DISTRACT_CONTROLLER_ONLINE', TO_NUMBER('41b', 'XXXXXXXXX'), '0x41b', 'Distributed Elevator Controller Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_DISTRACT_CONTROLLER_OFFLINE', TO_NUMBER('41c', 'XXXXXXXXX'), '0x41c', 'Distributed Elevator Controller Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_ID_CARD_READER_NOT_CONNECT', TO_NUMBER('41d', 'XXXXXXXXX'), '0x41d', 'ID Card Reader Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_ID_CARD_READER_RESUME', TO_NUMBER('41e', 'XXXXXXXXX'), '0x41e', 'ID Card Reader Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_FINGER_PRINT_MODULE_NOT_CONNECT', TO_NUMBER('41f', 'XXXXXXXXX'), '0x41f', 'Fingerprint Module Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_FINGER_PRINT_MODULE_RESUME', TO_NUMBER('420', 'XXXXXXXXX'), '0x420', 'Fingerprint Module Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CAMERA_NOT_CONNECT', TO_NUMBER('421', 'XXXXXXXXX'), '0x421', 'Camera Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CAMERA_RESUME', TO_NUMBER('422', 'XXXXXXXXX'), '0x422', 'Camera Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_COM_NOT_CONNECT', TO_NUMBER('423', 'XXXXXXXXX'), '0x423', 'COM Port Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_COM_RESUME', TO_NUMBER('424', 'XXXXXXXXX'), '0x424', 'COM Port Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_DEVICE_NOT_AUTHORIZE', TO_NUMBER('425', 'XXXXXXXXX'), '0x425', 'Device Unauthorized' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_PEOPLE_AND_ID_CARD_DEVICE_ONLINE', TO_NUMBER('426', 'XXXXXXXXX'), '0x426', 'Face Recognition Terminal Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_PEOPLE_AND_ID_CARD_DEVICE_OFFLINE', TO_NUMBER('427', 'XXXXXXXXX'), '0x427', 'Face Recognition Terminal Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_LOGIN_LOCK', TO_NUMBER('428', 'XXXXXXXXX'), '0x428', 'Local Login Lock' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LOCAL_LOGIN_UNLOCK', TO_NUMBER('429', 'XXXXXXXXX'), '0x429', 'Local Login Unlock' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_SUBMARINEBACK_COMM_BREAK', TO_NUMBER('42a', 'XXXXXXXXX'), '0x42a', 'Communication with Anti-passing Back Server Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_SUBMARINEBACK_COMM_RESUME', TO_NUMBER('42b', 'XXXXXXXXX'), '0x42b', 'Communication with Anti-passing Back Server Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_MOTOR_SENSOR_EXCEPTION', TO_NUMBER('42c', 'XXXXXXXXX'), '0x42c', 'Motor or Sensor Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CAN_BUS_EXCEPTION', TO_NUMBER('42d', 'XXXXXXXXX'), '0x42d', 'CAN Bus Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_CAN_BUS_RESUME', TO_NUMBER('42e', 'XXXXXXXXX'), '0x42e', 'CAN Bus Exception Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_GATE_TEMPERATURE_OVERRUN', TO_NUMBER('42f', 'XXXXXXXXX'), '0x42f', 'Too High Pedestal Temperature' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_IR_EMITTER_EXCEPTION', TO_NUMBER('430', 'XXXXXXXXX'), '0x430', 'Active Infrared Intrusion Detector Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_IR_EMITTER_RESUME', TO_NUMBER('431', 'XXXXXXXXX'), '0x431', 'Active Infrared Intrusion Detector Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LAMP_BOARD_COMM_EXCEPTION', TO_NUMBER('432', 'XXXXXXXXX'), '0x432', 'Communication with Light Board Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_LAMP_BOARD_COMM_RESUME', TO_NUMBER('433', 'XXXXXXXXX'), '0x433', 'Communication with Light Board Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_IR_ADAPTOR_COMM_EXCEPTION', TO_NUMBER('434', 'XXXXXXXXX'), '0x434', 'Communication with IR Adaptor Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_IR_ADAPTOR_COMM_RESUME', TO_NUMBER('435', 'XXXXXXXXX'), '0x435', 'Communication with IR Adaptor Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_PRINTER_ONLINE', TO_NUMBER('436', 'XXXXXXXXX'), '0x436', 'Printer Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_PRINTER_OFFLINE', TO_NUMBER('437', 'XXXXXXXXX'), '0x437', 'Printer Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_4G_MOUDLE_ONLINE', TO_NUMBER('438', 'XXXXXXXXX'), '0x438', '4G Module Online' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_4G_MOUDLE_OFFLINE', TO_NUMBER('439', 'XXXXXXXXX'), '0x439', '4G Module Offline' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_AUXILIARY_BOARD_OFFLINE', TO_NUMBER('43c', 'XXXXXXXXX'), '0x43c', 'Auxiliary Board Disconnected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_AUXILIARY_BOARD_RESUME', TO_NUMBER('43d', 'XXXXXXXXX'), '0x43d', 'Auxiliary Board Connected' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_IDCARD_SECURITY_MOUDLE_EXCEPTION', TO_NUMBER('43e', 'XXXXXXXXX'), '0x43e', 'Secure ID Card Unit Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_IDCARD_SECURITY_MOUDLE_RESUME', TO_NUMBER('43f', 'XXXXXXXXX'), '0x43f', 'Secure ID Card Unit Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_FP_PERIPHERAL_EXCEPTION', TO_NUMBER('440', 'XXXXXXXXX'), '0x440', 'Fingerprint Collection Peripheral Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 2, 'MINOR_FP_PERIPHERAL_RESUME', TO_NUMBER('441', 'XXXXXXXXX'), '0x441', 'Fingerprint Collection Peripheral Restored' FROM DUAL;
-- Operation
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_LOCAL_LOGIN', TO_NUMBER('50', 'XXXXXXXXX'), '0x50', 'Local Login' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_LOCAL_LOGOUT', TO_NUMBER('51', 'XXXXXXXXX'), '0x51', 'Local Logout' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_LOCAL_UPGRADE', TO_NUMBER('5a', 'XXXXXXXXX'), '0x5a', 'Local Upgrade' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_LOGIN', TO_NUMBER('70', 'XXXXXXXXX'), '0x70', 'Remote Login' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_LOGOUT', TO_NUMBER('71', 'XXXXXXXXX'), '0x71', 'Remote Logout' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ARM', TO_NUMBER('79', 'XXXXXXXXX'), '0x79', 'Remote Arming' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_DISARM', TO_NUMBER('7a', 'XXXXXXXXX'), '0x7a', 'Remote Disarming' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_REBOOT', TO_NUMBER('7b', 'XXXXXXXXX'), '0x7b', 'Remote Reboot' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_UPGRADE', TO_NUMBER('7e', 'XXXXXXXXX'), '0x7e', 'Remote Upgrade' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CFGFILE_OUTPUT', TO_NUMBER('86', 'XXXXXXXXX'), '0x86', 'Remote Operation: Export Configuration File' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CFGFILE_INTPUT', TO_NUMBER('87', 'XXXXXXXXX'), '0x87', 'Remote Operation: Import Configuration File' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ALARMOUT_OPEN_MAN', TO_NUMBER('d6', 'XXXXXXXXX'), '0xd6', 'Remote Operation: Enable Alarm Output Manually' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ALARMOUT_CLOSE_MAN', TO_NUMBER('d7', 'XXXXXXXXX'), '0xd7', 'Remote Operation: Disable Alarm Output Manually' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_OPEN_DOOR', TO_NUMBER('400', 'XXXXXXXXX'), '0x400', 'Door Remotely Open' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CLOSE_DOOR', TO_NUMBER('401', 'XXXXXXXXX'), '0x401', 'Door Remotely Closed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ALWAYS_OPEN', TO_NUMBER('402', 'XXXXXXXXX'), '0x402', 'Remain Open Remotely' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ALWAYS_CLOSE', TO_NUMBER('403', 'XXXXXXXXX'), '0x403', 'Remain Closed Remotely' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CHECK_TIME', TO_NUMBER('404', 'XXXXXXXXX'), '0x404', 'Remote: Manual Time Sync' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_NTP_CHECK_TIME', TO_NUMBER('405', 'XXXXXXXXX'), '0x405', 'Network Time Protocol Synchronization' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CLEAR_CARD', TO_NUMBER('406', 'XXXXXXXXX'), '0x406', 'Remote Operation: Clear All Card No.' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_RESTORE_CFG', TO_NUMBER('407', 'XXXXXXXXX'), '0x407', 'Remote Operation: Restore Defaults' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_ALARMIN_ARM', TO_NUMBER('408', 'XXXXXXXXX'), '0x408', 'Zone Arming' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_ALARMIN_DISARM', TO_NUMBER('409', 'XXXXXXXXX'), '0x409', 'Zone Disarming' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_LOCAL_RESTORE_CFG', TO_NUMBER('40a', 'XXXXXXXXX'), '0x40a', 'Local Operation: Restore Defaults' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CAPTURE_PIC', TO_NUMBER('40b', 'XXXXXXXXX'), '0x40b', 'Remote Operation: Capture' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_MOD_NET_REPORT_CFG', TO_NUMBER('40c', 'XXXXXXXXX'), '0x40c', 'Edit Network Parameters' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_MOD_GPRS_REPORT_PARAM', TO_NUMBER('40d', 'XXXXXXXXX'), '0x40d', 'Edit GPRS Parameters' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_MOD_REPORT_GROUP_PARAM', TO_NUMBER('40e', 'XXXXXXXXX'), '0x40e', 'Edit Control Center Parameters' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_UNLOCK_PASSWORD_OPEN_DOOR', TO_NUMBER('40f', 'XXXXXXXXX'), '0x40f', 'Enter Dismiss Code' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_AUTO_RENUMBER', TO_NUMBER('410', 'XXXXXXXXX'), '0x410', 'Auto Renumber' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_AUTO_COMPLEMENT_NUMBER', TO_NUMBER('411', 'XXXXXXXXX'), '0x411', 'Auto Supplement Number' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_NORMAL_CFGFILE_INPUT', TO_NUMBER('412', 'XXXXXXXXX'), '0x412', 'Import Configuration File' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_NORMAL_CFGFILE_OUTTPUT', TO_NUMBER('413', 'XXXXXXXXX'), '0x413', 'Export Configuration File' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_CARD_RIGHT_INPUT', TO_NUMBER('414', 'XXXXXXXXX'), '0x414', 'Import Card Permission Parameters' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_CARD_RIGHT_OUTTPUT', TO_NUMBER('415', 'XXXXXXXXX'), '0x415', 'Export Card Permission Parameters' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_LOCAL_USB_UPGRADE', TO_NUMBER('416', 'XXXXXXXXX'), '0x416', 'Upgrade Device via USB flash Drive' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_VISITOR_CALL_LADDER', TO_NUMBER('417', 'XXXXXXXXX'), '0x417', 'Visitor Calling Elevator' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_HOUSEHOLD_CALL_LADDER', TO_NUMBER('418', 'XXXXXXXXX'), '0x418', 'Resident Calling Elevator' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ACTUAL_GUARD', TO_NUMBER('419', 'XXXXXXXXX'), '0x419', 'Remotely Arming' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_ACTUAL_UNGUARD', TO_NUMBER('41a', 'XXXXXXXXX'), '0x41a', 'Remotely Disarming' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CONTROL_NOT_CODE_OPER_FAILED', TO_NUMBER('41b', 'XXXXXXXXX'), '0x41b', 'Operation Failed: Keyfob Not Pairing' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CONTROL_CLOSE_DOOR', TO_NUMBER('41c', 'XXXXXXXXX'), '0x41c', 'Keyfob Operation: Close Door' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CONTROL_OPEN_DOOR', TO_NUMBER('41d', 'XXXXXXXXX'), '0x41d', 'Keyfob Operation: Open Door' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_REMOTE_CONTROL_ALWAYS_OPEN_DOOR', TO_NUMBER('41e', 'XXXXXXXXX'), '0x41e', 'Keyfob Operation: Remain Door Open' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_M1_CARD_ENCRYPT_VERIFY_OPEN', TO_NUMBER('41f', 'XXXXXXXXX'), '0x41f', 'M1 Card Encryption Verification Enabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_M1_CARD_ENCRYPT_VERIFY_CLOSE', TO_NUMBER('420', 'XXXXXXXXX'), '0x420', 'M1 Card Encryption Verification Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_NFC_FUNCTION_OPEN', TO_NUMBER('421', 'XXXXXXXXX'), '0X421', 'Opening Door with NFC Card Enabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_NFC_FUNCTION_CLOSE', TO_NUMBER('422', 'XXXXXXXXX'), '0X422', 'Opening Door with NFC Card Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_OFFLINE_DATA_OUTPUT', TO_NUMBER('423', 'XXXXXXXXX'), '0x423', 'Export Offline Collected Data' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_CREATE_SSH_LINK', TO_NUMBER('42d', 'XXXXXXXXX'), '0x42d', 'Establish SSH Connection' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 3, 'MINOR_CLOSE_SSH_LINK', TO_NUMBER('42e', 'XXXXXXXXX'), '0x42e', 'Disconnect SSH Connection' FROM DUAL;
-- Event
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LEGAL_CARD_PASS', TO_NUMBER('01', 'XXXXXXXXX'), '0x01', 'Valid Card Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_AND_PSW_PASS', TO_NUMBER('02', 'XXXXXXXXX'), '0x02', 'Card and Password Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_AND_PSW_FAIL', TO_NUMBER('03', 'XXXXXXXXX'), '0x03', 'Card and Password Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_AND_PSW_TIMEOUT', TO_NUMBER('04', 'XXXXXXXXX'), '0x04', 'Card and Password Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_AND_PSW_OVER_TIME', TO_NUMBER('05', 'XXXXXXXXX'), '0x05', 'Card and Password Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_NO_RIGHT', TO_NUMBER('06', 'XXXXXXXXX'), '0x06', 'No Permission' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_INVALID_PERIOD', TO_NUMBER('07', 'XXXXXXXXX'), '0x07', 'Invalid Card Swiping Time Period' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_OUT_OF_DATE', TO_NUMBER('08', 'XXXXXXXXX'), '0x08', 'Expired Card' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_INVALID_CARD', TO_NUMBER('09', 'XXXXXXXXX'), '0x09', 'Card No. Not Exist' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ANTI_SNEAK_FAIL', TO_NUMBER('0a', 'XXXXXXXXX'), '0x0a', 'Anti-passing Back Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_INTERLOCK_DOOR_NOT_CLOSE', TO_NUMBER('0b', 'XXXXXXXXX'), '0x0b', 'Interlocking Door Not Closed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_NOT_BELONG_MULTI_GROUP', TO_NUMBER('0c', 'XXXXXXXXX'), '0x0c', 'Card Not in Multiple Authentication Group' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_INVALID_MULTI_VERIFY_PERIOD', TO_NUMBER('0d', 'XXXXXXXXX'), '0x0d', 'Card Not in Multiple Authentication Duration' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_SUPER_RIGHT_FAIL', TO_NUMBER('0e', 'XXXXXXXXX'), '0x0e', 'Multiple Authentications: Super Password Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_REMOTE_RIGHT_FAIL', TO_NUMBER('0f', 'XXXXXXXXX'), '0x0f', 'Multiple Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_SUCCESS', TO_NUMBER('10', 'XXXXXXXXX'), '0x10', 'Multiple Authenticated' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LEADER_CARD_OPEN_BEGIN', TO_NUMBER('11', 'XXXXXXXXX'), '0x11', 'Open Door with First Card Started' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LEADER_CARD_OPEN_END', TO_NUMBER('12', 'XXXXXXXXX'), '0x12', 'Open Door with First Card Stopped' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ALWAYS_OPEN_BEGIN', TO_NUMBER('13', 'XXXXXXXXX'), '0x13', 'Remain Open Started' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ALWAYS_OPEN_END', TO_NUMBER('14', 'XXXXXXXXX'), '0x14', 'Remain Open Stopped' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LOCK_OPEN', TO_NUMBER('15', 'XXXXXXXXX'), '0x15', 'Door Unlocked' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LOCK_CLOSE', TO_NUMBER('16', 'XXXXXXXXX'), '0x16', 'Door Locked' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_BUTTON_PRESS', TO_NUMBER('17', 'XXXXXXXXX'), '0x17', 'Exit Button Pressed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_BUTTON_RELEASE', TO_NUMBER('18', 'XXXXXXXXX'), '0x18', 'Exit Button Released' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_OPEN_NORMAL', TO_NUMBER('19', 'XXXXXXXXX'), '0x19', 'Door Open (Contact)' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_CLOSE_NORMAL', TO_NUMBER('1a', 'XXXXXXXXX'), '0x1a', 'Door Closed (Contact)' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_OPEN_ABNORMAL', TO_NUMBER('1b', 'XXXXXXXXX'), '0x1b', 'Door Abnormally Open (Contact)' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_OPEN_TIMEOUT', TO_NUMBER('1c', 'XXXXXXXXX'), '0x1c', 'Door Open Timed Out (Contact)' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ALARMOUT_ON', TO_NUMBER('1d', 'XXXXXXXXX'), '0x1d', 'Alarm Output Enabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ALARMOUT_OFF', TO_NUMBER('1e', 'XXXXXXXXX'), '0x1e', 'Alarm Output Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ALWAYS_CLOSE_BEGIN', TO_NUMBER('1f', 'XXXXXXXXX'), '0x1f', 'Remain Closed Started' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ALWAYS_CLOSE_END', TO_NUMBER('20', 'XXXXXXXXX'), '0x20', 'Remain Closed Stopped' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_NEED_REMOTE_OPEN', TO_NUMBER('21', 'XXXXXXXXX'), '0x21', 'Multiple Authentications: Remotely Open Door' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_SUPERPASSWD_VERIFY_SUCCESS', TO_NUMBER('22', 'XXXXXXXXX'), '0x22', 'Multiple Authentications: Super Password Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_REPEAT_VERIFY', TO_NUMBER('23', 'XXXXXXXXX'), '0x23', 'Multiple Authentications: Repeated Authentication' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_MULTI_VERIFY_TIMEOUT', TO_NUMBER('24', 'XXXXXXXXX'), '0x24', 'Multiple Authentications Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORBELL_RINGING', TO_NUMBER('25', 'XXXXXXXXX'), '0x25', 'Doorbell Ring' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FINGERPRINT_COMPARE_PASS', TO_NUMBER('26', 'XXXXXXXXX'), '0x26', 'Fingerprint Matched' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FINGERPRINT_COMPARE_FAIL', TO_NUMBER('27', 'XXXXXXXXX'), '0x27', 'Fingerprint Mismatched' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_FINGERPRINT_VERIFY_PASS', TO_NUMBER('28', 'XXXXXXXXX'), '0x28', 'Card and Fingerprint Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_FINGERPRINT_VERIFY_FAIL', TO_NUMBER('29', 'XXXXXXXXX'), '0x29', 'Card and Fingerprint Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_FINGERPRINT_VERIFY_TIMEOUT', TO_NUMBER('2a', 'XXXXXXXXX'), '0x2a', 'Card and Fingerprint Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_FINGERPRINT_PASSWD_VERIFY_PASS', TO_NUMBER('2b', 'XXXXXXXXX'), '0x2b', 'Card and Fingerprint and Password Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_FINGERPRINT_PASSWD_VERIFY_FAIL', TO_NUMBER('2c', 'XXXXXXXXX'), '0x2c', 'Card and Fingerprint and Password Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_FINGERPRINT_PASSWD_VERIFY_TIMEOUT', TO_NUMBER('2d', 'XXXXXXXXX'), '0x2d', 'Card and Fingerprint and Password Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FINGERPRINT_PASSWD_VERIFY_PASS', TO_NUMBER('2e', 'XXXXXXXXX'), '0x2e', 'Fingerprint and Password Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FINGERPRINT_PASSWD_VERIFY_FAIL', TO_NUMBER('2f', 'XXXXXXXXX'), '0x2f', 'Fingerprint and Password Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FINGERPRINT_PASSWD_VERIFY_TIMEOUT', TO_NUMBER('30', 'XXXXXXXXX'), '0x30', 'Fingerprint and Password Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FINGERPRINT_INEXISTENCE', TO_NUMBER('31', 'XXXXXXXXX'), '0x31', 'Fingerprint Not Exists' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_PLATFORM_VERIFY', TO_NUMBER('32', 'XXXXXXXXX'), '0x32', 'Card Platform Authentication' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CALL_CENTER', TO_NUMBER('33', 'XXXXXXXXX'), '0x33', 'Call Center' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FIRE_RELAY_TURN_ON_DOOR_ALWAYS_OPEN', TO_NUMBER('34', 'XXXXXXXXX'), '0x34', 'Fire Relay Closed: Door Remains Open' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FIRE_RELAY_RECOVER_DOOR_RECOVER_NORMAL', TO_NUMBER('35', 'XXXXXXXXX'), '0x35', 'Fire Relay Opened: Door Remains Closed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FP_VERIFY_PASS', TO_NUMBER('45', 'XXXXXXXXX'), '0x45', 'Employee ID and Fingerprint Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FP_VERIFY_FAIL', TO_NUMBER('46', 'XXXXXXXXX'), '0x46', 'Employee ID and Fingerprint Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FP_VERIFY_TIMEOUT', TO_NUMBER('47', 'XXXXXXXXX'), '0x47', 'Employee ID and Fingerprint Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FP_AND_PW_VERIFY_PASS', TO_NUMBER('48', 'XXXXXXXXX'), '0x48', 'Employee ID and Fingerprint and Password Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FP_AND_PW_VERIFY_FAIL', TO_NUMBER('49', 'XXXXXXXXX'), '0x49', 'Employee ID and Fingerprint and Password Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FP_AND_PW_VERIFY_TIMEOUT', TO_NUMBER('4a', 'XXXXXXXXX'), '0x4a', 'Employee ID and Fingerprint and Password Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FACE_VERIFY_PASS', TO_NUMBER('4b', 'XXXXXXXXX'), '0x4b', 'Face Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FACE_VERIFY_FAIL', TO_NUMBER('4c', 'XXXXXXXXX'), '0x4c', 'Face Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FACE_VERIFY_PASS', TO_NUMBER('4d', 'XXXXXXXXX'), '0x4d', 'Employee ID and Face Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FACE_VERIFY_FAIL', TO_NUMBER('4e', 'XXXXXXXXX'), '0x4e', 'Employee ID and Face Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_FACE_VERIFY_TIMEOUT', TO_NUMBER('4f', 'XXXXXXXXX'), '0x4f', 'Employee ID and Face Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FACE_RECOGNIZE_FAIL', TO_NUMBER('50', 'XXXXXXXXX'), '0x50', 'Face Recognition Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FIRSTCARD_AUTHORIZE_BEGIN', TO_NUMBER('51', 'XXXXXXXXX'), '0x51', 'First Card Authorization Started' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FIRSTCARD_AUTHORIZE_END', TO_NUMBER('52', 'XXXXXXXXX'), '0x52', 'First Card Authorization Ended' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORLOCK_INPUT_SHORT_CIRCUIT', TO_NUMBER('53', 'XXXXXXXXX'), '0x53', 'Lock Input Short Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORLOCK_INPUT_BROKEN_CIRCUIT', TO_NUMBER('54', 'XXXXXXXXX'), '0x54', 'Lock Input Open Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORLOCK_INPUT_EXCEPTION', TO_NUMBER('55', 'XXXXXXXXX'), '0x55', 'Lock Input Exception Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORCONTACT_INPUT_SHORT_CIRCUIT', TO_NUMBER('56', 'XXXXXXXXX'), '0x56', 'Contact Input Short Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORCONTACT_INPUT_BROKEN_CIRCUIT', TO_NUMBER('57', 'XXXXXXXXX'), '0x57', 'Contact Input Open Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORCONTACT_INPUT_EXCEPTION', TO_NUMBER('58', 'XXXXXXXXX'), '0x58', 'Contact Input Exception Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_OPENBUTTON_INPUT_SHORT_CIRCUIT', TO_NUMBER('59', 'XXXXXXXXX'), '0x59', 'Exit Button Input Short Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_OPENBUTTON_INPUT_BROKEN_CIRCUIT', TO_NUMBER('5a', 'XXXXXXXXX'), '0x5a', 'Exit Button Input Open Circuit Attempts Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_OPENBUTTON_INPUT_EXCEPTION', TO_NUMBER('5b', 'XXXXXXXXX'), '0x5b', 'Exit Button Input Exception Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORLOCK_OPEN_EXCEPTION', TO_NUMBER('5c', 'XXXXXXXXX'), '0x5c', 'Unlocking Exception' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOORLOCK_OPEN_TIMEOUT', TO_NUMBER('5d', 'XXXXXXXXX'), '0x5d', 'Unlocking Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FIRSTCARD_OPEN_WITHOUT_AUTHORIZE', TO_NUMBER('5e', 'XXXXXXXXX'), '0x5e', 'Unauthorized First Card Opening Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CALL_LADDER_RELAY_BREAK', TO_NUMBER('5f', 'XXXXXXXXX'), '0x5f', 'Call Elevator Relay Open' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CALL_LADDER_RELAY_CLOSE', TO_NUMBER('60', 'XXXXXXXXX'), '0x60', 'Call Elevator Relay Closed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_AUTO_KEY_RELAY_BREAK', TO_NUMBER('61', 'XXXXXXXXX'), '0x61', 'Auto Button Relay Open' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_AUTO_KEY_RELAY_CLOSE', TO_NUMBER('62', 'XXXXXXXXX'), '0x62', 'Auto Button Relay Closed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_KEY_CONTROL_RELAY_BREAK', TO_NUMBER('63', 'XXXXXXXXX'), '0x63', 'Button Relay Open' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_KEY_CONTROL_RELAY_CLOSE', TO_NUMBER('64', 'XXXXXXXXX'), '0x64', 'Button Relay Closed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_PW_PASS', TO_NUMBER('65', 'XXXXXXXXX'), '0x65', 'Employee ID and Password Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_PW_FAIL', TO_NUMBER('66', 'XXXXXXXXX'), '0x66', 'Employee ID and Password Authentication Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEENO_AND_PW_TIMEOUT', TO_NUMBER('67', 'XXXXXXXXX'), '0x67', 'Employee ID and Password Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CERTIFICATE_BLACK_LIST', TO_NUMBER('71', 'XXXXXXXXX'), '0x71', 'Blacklist Event' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LEGAL_MESSAGE', TO_NUMBER('72', 'XXXXXXXXX'), '0x72', 'Valid Message' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ILLEGAL_MESSAGE', TO_NUMBER('73', 'XXXXXXXXX'), '0x73', 'Invalid Message' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_OPEN_OR_DORMANT_FAIL', TO_NUMBER('75', 'XXXXXXXXX'), '0x75', 'Authentication Failed: Door Remain Closed or Door in Sleeping Mode' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_AUTH_PLAN_DORMANT_FAIL', TO_NUMBER('76', 'XXXXXXXXX'), '0x76', 'Authentication Failed: Authentication Schedule in Sleeping Mode' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_ENCRYPT_VERIFY_FAIL', TO_NUMBER('77', 'XXXXXXXXX'), '0x77', 'Card Encryption Verification Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_SUBMARINEBACK_REPLY_FAIL', TO_NUMBER('78', 'XXXXXXXXX'), '0x78', 'Anti-passing Back Server Response Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_OPEN_OR_DORMANT_OPEN_FAIL', TO_NUMBER('82', 'XXXXXXXXX'), '0x82', 'Open Door via Exit Button Failed When Door Remain Closed or in Sleeping Mode' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DOOR_OPEN_OR_DORMANT_LINKAGE_OPEN_FAIL', TO_NUMBER('84', 'XXXXXXXXX'), '0x84', 'Door Linkage Open Failed During Door Remain Close or Sleeping' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_TRAILING', TO_NUMBER('85', 'XXXXXXXXX'), '0x85', 'Tailgating' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_REVERSE_ACCESS', TO_NUMBER('86', 'XXXXXXXXX'), '0x86', 'Reverse Passing' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FORCE_ACCESS', TO_NUMBER('87', 'XXXXXXXXX'), '0x87', 'Force Accessing' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CLIMBING_OVER_GATE', TO_NUMBER('88', 'XXXXXXXXX'), '0x88', 'Climb Over' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_PASSING_TIMEOUT', TO_NUMBER('89', 'XXXXXXXXX'), '0x89', 'Passing Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_INTRUSION_ALARM', TO_NUMBER('8a', 'XXXXXXXXX'), '0x8a', 'Intrusion Alarm' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_FREE_GATE_PASS_NOT_AUTH', TO_NUMBER('8b', 'XXXXXXXXX'), '0x8b', 'Authentication Failed When Free Passing' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DROP_ARM_BLOCK', TO_NUMBER('8c', 'XXXXXXXXX'), '0x8c', 'Barrier Obstructed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DROP_ARM_BLOCK_RESUME', TO_NUMBER('8d', 'XXXXXXXXX'), '0x8d', 'Barrier Restored' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_PASSWORD_MISMATCH', TO_NUMBER('97', 'XXXXXXXXX'), '0x97', 'Passwords Mismatched' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EMPLOYEE_NO_NOT_EXIST', TO_NUMBER('98', 'XXXXXXXXX'), '0x98', 'Employee ID Not Exists' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_COMBINED_VERIFY_PASS', TO_NUMBER('99', 'XXXXXXXXX'), '0x99', 'Combined Authentication Completed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_COMBINED_VERIFY_TIMEOUT', TO_NUMBER('9a', 'XXXXXXXXX'), '0x9a', 'Combined Authentication Timed Out' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_VERIFY_MODE_MISMATCH', TO_NUMBER('9b', 'XXXXXXXXX'), '0x9b', 'Authentication Type Mismatched' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_INFORMAL_MIFARE_CARD_VERIFY_FAIL', TO_NUMBER('a2', 'XXXXXXXXX'), '0xa2', 'Authentication Failed: Invalid Mifare Card' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CPU_CARD_ENCRYPT_VERIFY_FAIL', TO_NUMBER('a3', 'XXXXXXXXX'), '0xa3', 'Verifying CPU Card Encryption Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_NFC_DISABLE_VERIFY_FAIL', TO_NUMBER('a4', 'XXXXXXXXX'), '0xa4', 'Disabling NFC Verification Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_EM_CARD_RECOGNIZE_NOT_ENABLED', TO_NUMBER('a8', 'XXXXXXXXX'), '0xa8', 'EM Card Recognition Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_M1_CARD_RECOGNIZE_NOT_ENABLED', TO_NUMBER('a9', 'XXXXXXXXX'), '0xa9', 'M1 Card Recognition Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CPU_CARD_RECOGNIZE_NOT_ENABLED', TO_NUMBER('aa', 'XXXXXXXXX'), '0xaa', 'CPU Card Recognition Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_ID_CARD_RECOGNIZE_NOT_ENABLED', TO_NUMBER('ab', 'XXXXXXXXX'), '0xab', 'ID Card Recognition Disabled' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_CARD_SET_SECRET_KEY_FAIL', TO_NUMBER('ac', 'XXXXXXXXX'), '0xac', 'Importing Key to Card Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_LOCAL_UPGRADE_FAIL', TO_NUMBER('ad', 'XXXXXXXXX'), '0xad', 'Local Upgrade Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_REMOTE_UPGRADE_FAIL', TO_NUMBER('ae', 'XXXXXXXXX'), '0xae', 'Remote Upgrade Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_REMOTE_EXTEND_MODULE_UPGRADE_SUCC', TO_NUMBER('af', 'XXXXXXXXX'), '0xaf', 'Extension Module is Remotely Upgraded' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_REMOTE_EXTEND_MODULE_UPGRADE_FAIL', TO_NUMBER('b0', 'XXXXXXXXX'), '0xb0', 'Upgrading Extension Module Remotely Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_REMOTE_FINGER_PRINT_MODULE_UPGRADE_SUCC', TO_NUMBER('b1', 'XXXXXXXXX'), '0xb1', 'Fingerprint Module is Remotely Upgraded' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_REMOTE_FINGER_PRINT_MODULE_UPGRADE_FAIL', TO_NUMBER('b2', 'XXXXXXXXX'), '0xb2', 'Upgrading Fingerprint Module Remotely Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DYNAMICCODE_VERIFY_PASS', TO_NUMBER('b3', 'XXXXXXXXX'), '0xb3', 'Dynamic Verification Code Authenticated' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_DYNAMICCODE_VERIFY_FAIL', TO_NUMBER('b4', 'XXXXXXXXX'), '0xb4', 'Authentication with Verification Code Failed' FROM DUAL;
INSERT INTO HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID, HIK_MAJ_EV_TYPE_ID, EV_TYPE, MIN_EV_ID, CODE, NAME) SELECT HIK_MIN_EV_TYPE_SEQ.NextVal, 5, 'MINOR_PASSWD_VERIFY_PASS', TO_NUMBER('b5', 'XXXXXXXXX'), '0xb5', 'Password Authenticated' FROM DUAL;

CREATE TABLE HIK_EVENT (
	HIK_EVENT_ID NUMBER NOT NULL,
	HIK_CAMERA_ID NUMBER NOT NULL,
	HIK_MIN_EV_TYPE_ID NUMBER NOT NULL,
	DT DATE NOT NULL,
	CARD_TYPE NUMBER,
	NAME VARCHAR2(250 CHAR),
	CARD_READER_NO NUMBER,
	DOOR_NO NUMBER,
	EMPLOYEE_NO_STR VARCHAR2(250 CHAR),
	ZONE_TYPE NUMBER,
	SERIAL_NO NUMBER,
	USER_TYPE VARCHAR2(100 CHAR),
	CURRENT_VERIFY_MODE VARCHAR2(250 CHAR),
	MASK VARCHAR2(100 CHAR),
	NET_USER VARCHAR2(100 CHAR),
	REMOTE_HOST_ADDR VARCHAR2(200 CHAR),
	CARD_NO VARCHAR2(100 CHAR),
	ATTENDANCE_STATUS VARCHAR2(200 CHAR),
	CONSTRAINT HIK_EVENT_PK PRIMARY KEY(HIK_EVENT_ID),
	CONSTRAINT HIK_MIN_EV_TYPE_FK FOREIGN KEY (HIK_MIN_EV_TYPE_ID) REFERENCES HIK_MIN_EV_TYPE (HIK_MIN_EV_TYPE_ID),
	CONSTRAINT HIK_MIN_EV_TYPE_CAMERA_FK FOREIGN KEY (HIK_CAMERA_ID) REFERENCES HIK_CAMERA (HIK_CAMERA_ID)
);

CREATE SEQUENCE HIK_EVENT_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER NOCYCLE;

CREATE INDEX HIK_EVENT_IDX_01 ON HIK_EVENT (HIK_CAMERA_ID, DT);

CREATE INDEX HIK_EVENT_IDX_02 ON HIK_EVENT (HIK_CAMERA_ID, SERIAL_NO);

CREATE VIEW V_HIK_EVENT AS
SELECT
	E.HIK_EVENT_ID,
	E.HIK_CAMERA_ID,
	E.HIK_MIN_EV_TYPE_ID,
	E.DT,
	E.CARD_TYPE,
	E.NAME,
	E.CARD_READER_NO,
	E.DOOR_NO,
	E.EMPLOYEE_NO_STR,
	E.ZONE_TYPE,
	E.SERIAL_NO,
	E.USER_TYPE,
	E.CURRENT_VERIFY_MODE,
	E.MASK,
	E.NET_USER,
	E.REMOTE_HOST_ADDR,
	E.CARD_NO,
	E.ATTENDANCE_STATUS,
    C.NAME AS CAMERA_NAME,
    C.BASE_URL AS CAMERA_BASE_URL,
    EN.CODE AS MIN_EVENT_TYPE_CODE,
    EN.NAME AS MIN_EVENT_TYPE_NAME,
    EM.NAME AS MAJ_EVENT_TYPE_NAME,
	EM.HIK_MAJ_EV_TYPE_ID
FROM
	HIK_EVENT E
    LEFT OUTER JOIN HIK_CAMERA C ON C.HIK_CAMERA_ID = E.HIK_CAMERA_ID
    LEFT OUTER JOIN HIK_MIN_EV_TYPE EN ON EN.HIK_MIN_EV_TYPE_ID = E.HIK_MIN_EV_TYPE_ID
    LEFT OUTER JOIN HIK_MAJ_EV_TYPE EM ON EM.HIK_MAJ_EV_TYPE_ID = EN.HIK_MAJ_EV_TYPE_ID
;

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (2129, SYSDATE, '5.5', 2049, 'HIKVISION Access Log')
;
